package com.ruoyi.zongzhi.mapper;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcZhongdianDomain;

/**
 * 重点领域监管Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface TcZhongdianDomainMapper 
{
    /**
     * 查询重点领域监管
     * 
     * @param id 重点领域监管主键
     * @return 重点领域监管
     */
    public TcZhongdianDomain selectTcZhongdianDomainById(Long id);

    /**
     * 查询重点领域监管列表
     * 
     * @param tcZhongdianDomain 重点领域监管
     * @return 重点领域监管集合
     */
    public List<TcZhongdianDomain> selectTcZhongdianDomainList(TcZhongdianDomain tcZhongdianDomain);

    /**
     * 新增重点领域监管
     * 
     * @param tcZhongdianDomain 重点领域监管
     * @return 结果
     */
    public int insertTcZhongdianDomain(TcZhongdianDomain tcZhongdianDomain);

    /**
     * 修改重点领域监管
     * 
     * @param tcZhongdianDomain 重点领域监管
     * @return 结果
     */
    public int updateTcZhongdianDomain(TcZhongdianDomain tcZhongdianDomain);

    /**
     * 删除重点领域监管
     * 
     * @param id 重点领域监管主键
     * @return 结果
     */
    public int deleteTcZhongdianDomainById(Long id);

    /**
     * 批量删除重点领域监管
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcZhongdianDomainByIds(Long[] ids);
}
