package com.ruoyi.zongzhi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcZhongdianDomain;
import com.ruoyi.zongzhi.service.ITcZhongdianDomainService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 重点领域监管Controller
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@RestController
@RequestMapping("/zongzhi/domain")
@Api(tags = "重点领域监管")
public class TcZhongdianDomainController extends BaseController
{
    @Autowired
    private ITcZhongdianDomainService tcZhongdianDomainService;

    /**
     * 查询重点领域监管列表
     */

    @GetMapping("/list")
    public TableDataInfo list(TcZhongdianDomain tcZhongdianDomain)
    {
        startPage();
        List<TcZhongdianDomain> list = tcZhongdianDomainService.selectTcZhongdianDomainList(tcZhongdianDomain);
        return getDataTable(list);
    }

    /**
     * 导出重点领域监管列表
     */

    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZhongdianDomain tcZhongdianDomain)
    {
        List<TcZhongdianDomain> list = tcZhongdianDomainService.selectTcZhongdianDomainList(tcZhongdianDomain);
        ExcelUtil<TcZhongdianDomain> util = new ExcelUtil<TcZhongdianDomain>(TcZhongdianDomain.class);
        util.exportExcel(response, list, "重点领域监管数据");
    }

    /**
     * 获取重点领域监管详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcZhongdianDomainService.selectTcZhongdianDomainById(id));
    }

    /**
     * 新增重点领域监管
     */

    @PostMapping
    public AjaxResult add(@RequestBody TcZhongdianDomain tcZhongdianDomain)
    {
        tcZhongdianDomain.setIsStatus(true);
        return toAjax(tcZhongdianDomainService.insertTcZhongdianDomain(tcZhongdianDomain));
    }

    /**
     * 修改重点领域监管
     */

    @PutMapping
    public AjaxResult edit(@RequestBody TcZhongdianDomain tcZhongdianDomain)
    {
        return toAjax(tcZhongdianDomainService.updateTcZhongdianDomain(tcZhongdianDomain));
    }

    /**
     * 删除重点领域监管
     */

	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcZhongdianDomainService.deleteTcZhongdianDomainByIds(ids));
    }
}
